package com.ruoyi.project.system.service.impl;

import java.util.Date;
import java.util.List;
import java.util.UUID;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.ServletUtils;
import com.ruoyi.framework.security.LoginUser;
import com.ruoyi.framework.security.service.TokenService;
import com.ruoyi.project.system.domain.SysUser;
import com.sun.jna.platform.win32.Guid;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.system.mapper.NotifyMapper;
import com.ruoyi.project.system.domain.Notify;
import com.ruoyi.project.system.service.INotifyService;

/**
 * 通知管理Service业务层处理
 *
 * @author yf
 * @date 2020-07-07
 */
@Service
public class NotifyServiceImpl implements INotifyService
{
    @Autowired
    private NotifyMapper notifyMapper;
    TokenService tokenService=new TokenService();

    /**
     * 查询通知管理
     *
     * @param id 通知管理ID
     * @return 通知管理
     */
    @Override
    public Notify selectNotifyById(Long id)
    {
        return notifyMapper.selectNotifyById(id);
    }

    /**
     * 已发通知列表
     *
     * @param notify 通知管理
     * @return 通知管理
     */
    @Override
    public List<Notify> selectNotifyList(Notify notify)
    {
// 获取当前的用户信息
        LoginUser currentUser = SecurityUtils.getLoginUser();
// 获取当前的用户名称
        String userName = currentUser.getUsername();
        notify.setSendperson(userName);
        return notifyMapper.selectNotifyList(notify);
    }

    /**
     * 收取通知列表
     *
     * @param notify 通知管理
     * @return 通知管理
     */
    @Override
    public List<Notify> selectRecvNotifyList(Notify notify,Long deptFlg)
    {
// 获取当前的用户信息
        LoginUser currentUser = SecurityUtils.getLoginUser();
// 获取当前的用户名称
        String userName = currentUser.getUsername();
        notify.setRecvperson(userName);
        notify.setDeptflg(deptFlg);
        return notifyMapper.selectRecvNotifyList(notify);
    }

    /**
     * 新增通知管理
     *
     * @param notify 通知管理
     * @return 结果
     */
    @Override
    public int insertNotify(Notify notify) {
        notify.setGuid(UUID.randomUUID().toString());
        notify.setSendtime(DateUtils.getNowDate());
// 获取当前的用户信息
        LoginUser currentUser = SecurityUtils.getLoginUser();
// 获取当前的用户名称
        String userName = currentUser.getUsername();
        notify.setSendperson(userName);
        return notifyMapper.insertNotify(notify);
    }

    /**
     * 修改通知管理
     *
     * @param notify 通知管理
     * @return 结果
     */
    @Override
    public int updateNotify(Notify notify)
    {
        notify.setRecvtime(null);
        return notifyMapper.updateNotify(notify);
    }

    /**
     * 批量删除通知管理
     *
     * @param ids 需要删除的通知管理ID
     * @return 结果
     */
    @Override
    public int deleteNotifyByIds(Long[] ids)
    {
        return notifyMapper.deleteNotifyByIds(ids);
    }

    /**
     * 删除通知管理信息
     *
     * @param id 通知管理ID
     * @return 结果
     */
    @Override
    public int deleteNotifyById(Long id)
    {
        return notifyMapper.deleteNotifyById(id);
    }
}
